Home
====

.. image:: https://secure.travis-ci.org/d0ugal/home.png
   :alt: Build Status
   :target: https://travis-ci.org/d0ugal/home

Codes for automating your house. WIP project by Dougal Matthews.
